file_tag

Function file_tag 

pub fn file_tag(given: &str, entry: Option<&Path>, module: &Path) -> String
the file a diagnostic is reported against: the entry module by the path given on the command line, any other module by its absolute path