pub fn open_universe(file: &str) -> LoadResultExpand description
the module graph of an entry file inside its package universe (manifest and lock diagnostics first), as the reference CLI opens it
pub fn open_universe(file: &str) -> LoadResultthe module graph of an entry file inside its package universe (manifest and lock diagnostics first), as the reference CLI opens it