judge_fixture

Function judge_fixture 

pub fn judge_fixture(file: &Path, is_valid: bool) -> Verdict
Judge one fixture (tests/validation/README.md): a valid one must parse, check, and evaluate clean; an invalid one must fail in the phase and with the code (and message) its @expect-* comments name.